==> qtmobility_1.1.0.orig.tar.gz: qt-mobility-opensource-src-1.1.0/examples/documentproperties/documentpropertieswidget.h <==
/****************************************************************************
**
** Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
** All rights reserved.
** Contact: Nokia Corporation (qt-info@nokia.com)
**
** This file is part of the Qt Mobility Components.
**
** $QT_BEGIN_LICENSE:BSD$
** You may use this file under the terms of the BSD license as follows:
**
** "Redistribution and use in source and binary forms, with or without
** modification, are permitted provided that the following conditions are
** met:
**   * Redistributions of source code must retain the above copyright
**     notice, this list of conditions and the following disclaimer.
**   * Redistributions in binary form must reproduce the above copyright
**     notice, this list of conditions and the following disclaimer in
**     the documentation and/or other materials provided with the
**     distribution.
**   * Neither the name of Nokia Corporation and its Subsidiary(-ies) nor
**     the names of its contributors may be used to endorse or promote
**     products derived from this software without specific prior written
**     permission.
**
** THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
** "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
** LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
** A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
** OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
** SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
** LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
** DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
** THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
** (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
** OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE."
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef DOCUMENTPROPERTIESWIDGET_H
#define DOCUMENTPROPERTIESWIDGET_H

#include <qmobilityglobal.h>

#include <QtCore/QVariant>
#include <QtGui/QDialog>

QT_BEGIN_NAMESPACE
class QFileInfo;
QT_END_NAMESPACE

QTM_BEGIN_NAMESPACE
class QDocumentGallery;
class QGalleryQueryRequest;
class QGalleryResultSet;
QTM_END_NAMESPACE


QTM_USE_NAMESPACE

class DocumentPropertiesWidget : public QWidget
{
    Q_OBJECT
public:
    DocumentPropertiesWidget(
            const QFileInfo &file,
            QDocumentGallery *gallery,
            QWidget *parent = 0,
            Qt::WindowFlags flags = 0);

private slots:
    void itemsInserted(int index, int count);
    void itemsRemoved(int index, int count);
    void metaDataChanged(int index, int count, const QList<int> &keys);

    void requestAudioProperties();
    void requestDocumentProperties();
    void requestImageProperties();
    void requestVideoProperties();

private:
    void requestProperties(
            const QString &itemType, const QStringList &propertyNames, const QStringList &labels);
    void insertRow(int index, const QString &propertyName, const QString &label);
    void updateValue(int widgetIndex, int propertyKey);

    QGalleryQueryRequest *request;
    QGalleryResultSet *resultSet;
    QList<int> propertyKeys;
    QList<QWidget *> widgets;
};

#endif

==> qtmobility_1.2.0.orig.tar.gz: qt-mobility-opensource-src-1.2.0/examples/documentproperties/documentpropertieswidget.h <==
/****************************************************************************
**
** Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
** All rights reserved.
** Contact: Nokia Corporation (qt-info@nokia.com)
**
** This file is part of the examples of the Qt Mobility Components.
**
** $QT_BEGIN_LICENSE:BSD$
** You may use this file under the terms of the BSD license as follows:
**
** "Redistribution and use in source and binary forms, with or without
** modification, are permitted provided that the following conditions are
** met:
**   * Redistributions of source code must retain the above copyright
**     notice, this list of conditions and the following disclaimer.
**   * Redistributions in binary form must reproduce the above copyright
**     notice, this list of conditions and the following disclaimer in
**     the documentation and/or other materials provided with the
**     distribution.
**   * Neither the name of Nokia Corporation and its Subsidiary(-ies) nor
**     the names of its contributors may be used to endorse or promote
**     products derived from this software without specific prior written
**     permission.
**
** THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
** "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
** LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
** A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
** OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
** SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
** LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
** DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
** THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
** (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
** OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE."
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef DOCUMENTPROPERTIESWIDGET_H
#define DOCUMENTPROPERTIESWIDGET_H

#include <qmobilityglobal.h>

#include <QtCore/QVariant>
#include <QtGui/QDialog>

QT_BEGIN_NAMESPACE
class QFileInfo;
QT_END_NAMESPACE

QTM_BEGIN_NAMESPACE
class QDocumentGallery;
class QGalleryItemRequest;
class QGalleryQueryRequest;
class QGalleryResultSet;
QTM_END_NAMESPACE


QTM_USE_NAMESPACE

class DocumentPropertiesWidget : public QDialog
{
    Q_OBJECT
public:
    DocumentPropertiesWidget(
            const QFileInfo &file,
            QDocumentGallery *gallery,
            QWidget *parent = 0,
            Qt::WindowFlags flags = 0);

private slots:
    void queryRequestFinished();

private:
    void requestAudioProperties();
    void requestDocumentProperties();
    void requestImageProperties();
    void requestVideoProperties();

    void makeItemRequestForProperties(const QStringList &propertyNames);

    void addTextPropertyRow(const char *rowTitle, const QString &propertyName);
    void addTimePropertyRow(const char *rowTitle, const QString &propertyName);
    void addRowWithTitleAndValue(const char *rowTitle, QWidget *propertyValue);

    QDocumentGallery *documentGallery;
    QGalleryQueryRequest *queryRequest;
    QGalleryItemRequest *itemRequest;
    QGalleryResultSet *resultSet;
};

#endif
